mkalen 2005/03/16 03:40:38
Modified: src/java/org/apache/ojb/broker/platforms
PlatformOracle9iImpl.java
Log:
Merge with OJB_1_0_RELEASE branch: Patch by Don Lyon: add support for
Oracle-extensions and large LOB support using Oracle9i with JBoss.
Revision Changes Path
1.18 +17 -13
db-ojb/src/java/org/apache/ojb/broker/platforms/PlatformOracle9iImpl.java
Index: PlatformOracle9iImpl.java
===================================================================
RCS file:
/home/cvs/db-ojb/src/java/org/apache/ojb/broker/platforms/PlatformOracle9iImpl.java,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -r1.17 -r1.18
--- PlatformOracle9iImpl.java 15 Mar 2005 02:50:45 -0000 1.17
+++ PlatformOracle9iImpl.java 16 Mar 2005 11:40:38 -0000 1.18
@@ -1,6 +1,6 @@
package org.apache.ojb.broker.platforms;
-/* Copyright 2003-2004 The Apache Software Foundation
+/* Copyright 2003-2005 The Apache Software Foundation
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -117,10 +117,11 @@
/** Method names used by [EMAIL PROTECTED] #unwrapConnection}. */
protected static final String UNWRAP_CONN_METHOD_NAMES[] =
{
- "unwrapCompletely" /* Oracle 10g */,
- "getInnermostDelegate" /* Commons DBCP */,
- "getVendorConnection" /* BEA WebLogic */,
- "getJDBC" /* P6Spy */
+ "unwrapCompletely" /* Oracle 10g */,
+ "getInnermostDelegate" /* Commons DBCP */,
+ "getUnderlyingConnection" /* JBoss */,
+ "getVendorConnection" /* BEA WebLogic */,
+ "getJDBC" /* P6Spy */
};
/**
* Method parameter signature used by [EMAIL PROTECTED]
#unwrapConnection} for corresponding
@@ -131,15 +132,17 @@
protected static final Class[][] UNWRAP_CONN_PARAM_TYPES =
{
null /* Index 0 reserved for Oracle 10g - initialized in
constructor */,
- PARAM_TYPE_EMPTY /* Commons DBCP */,
- PARAM_TYPE_EMPTY /* BEA WebLogic */,
- PARAM_TYPE_EMPTY /* P6Spy */
+ PARAM_TYPE_EMPTY /* Commons DBCP */,
+ PARAM_TYPE_EMPTY /* JBoss */,
+ PARAM_TYPE_EMPTY /* BEA WebLogic */,
+ PARAM_TYPE_EMPTY /* P6Spy */
};
/** Method names used by [EMAIL PROTECTED] #unwrapStatement}. */
protected static final String UNWRAP_PS_METHOD_NAMES[] =
{
- "getInnermostDelegate" /* Commons DBCP */,
- "getJDBC" /* P6Spy */
+ "getInnermostDelegate" /* Commons DBCP */,
+ "getUnderlyingStatement" /* JBoss */,
+ "getJDBC" /* P6Spy */
};
/**
* Method parameter signature used by [EMAIL PROTECTED]
#unwrapStatement} for corresponding
@@ -149,8 +152,9 @@
*/
protected static final Class[][] UNWRAP_PS_PARAM_TYPES =
{
- PARAM_TYPE_EMPTY /* Commons DBCP */,
- PARAM_TYPE_EMPTY /* P6Spy */
+ PARAM_TYPE_EMPTY /* Commons DBCP */,
+ PARAM_TYPE_EMPTY /* JBoss */,
+ PARAM_TYPE_EMPTY /* P6Spy */
};
---------------------------------------------------------------------
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]